/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * Determine the IP of the local machine. We have many 
 * ways to get that IP:
 * a) from the interface (ifconfig)
 * b) via DNS from our HOSTNAME (environment)
 * c) from the configuration (HOSTNAME specification or static IP)
 *
 * Which way applies depends on the OS, the configuration
 * (dynDNS? static IP? NAT?) and at the end what the user 
 * needs.
 *
 * @file include/identity.h
 * @author Christian Grothoff
 * @author Tzvetan Horozov
 **/

#ifndef IDENTITY_H
#define IDENTITY_H

#include "config.h"

#include "util/ipcheck.h"

/** 
 * Initialize identity module. Requries configuration.
 **/
void initAddress();

/** 
 * Shutdown identity module.
 **/
void doneAddress();

/**
 * Get the IP address for the local machine.
 * @return SYSERR on error, OK on success
 **/
int getPublicIPAddress(IPaddr  * address);


#endif
/* end of identity.h */
